# SpecPhot

A Python package for performing spectrophotometric calculations.

## Features
- Calculate synthetic photometry given a spectrum and a bandpass.

---

## Installation

### From GitHub
To install the latest version directly from GitHub, run:
```bash
pip install git+https://github.com/leonardo-clarke/specphot.git
```

### With pip
The package can be simply pip installed:
```bash
pip install specphot
```
## License
This project is licensed under the MIT License. See the [LICENSE](LICENSE) file for details.
